@@ -2,6 +2,44 @@ from aerosandbox.geometry import *
 from aerosandbox.performance import OperatingPoint
 import aerosandbox.numpy as np
 import aerosandbox.library.aerodynamics as aerolib
+from aerosandbox.library.aerodynamics import transonic
+
+
+def critical_mach(fineness_ratio_nose: float) -> float:
+    """
+    Returns the transonic critical Mach number for a streamlined fuselage.
+
+    Fitted to data from Raymer "Aircraft Design: A Conceptual Approach" 2nd Ed., Fig. 12.28.
+    See figure + study + fit in: /studies/FuselageCriticalMach/
+
+    Args:
+
+        fineness_ratio_nose: The fineness ratio of the nose section of the fuselage.
+
+            Specifically, fineness_ratio_nose = 2 * L_n / d, where:
+
+                * L_n is the length from the nose to the longitudinal location at which the fuselage cross section
+                becomes essentially constant, and:
+
+                * d is the body diameter at that location.
+
+    Returns: The critical Mach number
+
+    """
+    p = {
+        'a': 11.087202397070559,
+        'b': 13.469755774708842,
+        'c': 4.034476257077558
+    }
+
+    mach_dd = 1 - (p["a"] / (2 * fineness_ratio_nose + p["b"])) ** p["c"]
+
+    ### The following approximate relation is derived in W.H. Mason, "Configuration Aerodynamics", Chapter 7. Transonic Aerodynamics of Airfoils and Wings.
+    ### Equation 7-8 on Page 7-19.
+    ### This is in turn based on Lock's proposed empirically-derived shape of the drag rise, from Hilton, W.F., High Speed Aerodynamics, Longmans, Green & Co., London, 1952, pp. 47-49
+    mach_crit = mach_dd - (0.1 / 80) ** (1 / 3)
+
+    return mach_crit
 
 
 def jorgensen_eta(fineness_ratio: float) -> float:
@@ -14,7 +52,7 @@ def jorgensen_eta(fineness_ratio: float) -> float:
     Fits performed in /studies/JorgensenEtaFitting/
 
     Args:
-        fineness_ratio: The fineness ratio of the fuselage.
+        fineness_ratio: The fineness ratio of the fuselage. (length / diameter)
 
     Returns: An estimate of eta.
 
@@ -54,7 +92,6 @@ def fuselage_aerodynamics(
     Returns:
 
     """
-
     fuselage.Re = op_point.reynolds(reference_length=fuselage.length())
 
     ####### Reference quantities (Set these 1 here, just so we can follow Jorgensen syntax.)
@@ -75,8 +112,21 @@ def fuselage_aerodynamics(
     ### Skin friction drag
     C_D_skin = C_f_forebody * fuselage.area_wetted() / S_ref
 
+    ### Wave drag
+    sears_haack_drag = transonic.sears_haack_drag_from_volume(
+        volume=fuselage.volume(),
+        length=fuselage.length()
+    )
+    C_D_wave = transonic.approximate_CD_wave(
+        mach=op_point.mach(),
+        mach_crit=critical_mach(
+            fineness_ratio_nose=fuselage.fineness_ratio() / 2
+        ),
+        CD_wave_at_fully_supersonic=2.0 * sears_haack_drag
+    )
+
     ### Total zero-lift drag
-    C_D_zero_lift = C_D_skin + C_D_base
+    C_D_zero_lift = C_D_skin + C_D_base + C_D_wave
 
     ####### Jorgensen model
 
@@ -84,18 +134,19 @@ def fuselage_aerodynamics(
     x_w, y_w, z_w = op_point.convert_axes(
         1, 0, 0, from_axes="body", to_axes="wind"
     )
-    generalized_alpha = np.arccosd(x_w/(1+1e-14))
+    generalized_alpha = np.arccosd(x_w / (1 + 1e-14))
     sin_generalized_alpha = np.sind(generalized_alpha)
     cos_generalized_alpha = x_w
 
+    # ### Limit generalized alpha to -90 < alpha < 90, for now.
+    # generalized_alpha = np.clip(generalized_alpha, -90, 90)
+    # # TODO make the drag/moment functions not give negative results for alpha > 90.
+
     alpha_fractional_component = -z_w / np.sqrt(
         y_w ** 2 + z_w ** 2 + 1e-16)  # The fraction of any "generalized lift" to be in the direction of alpha
     beta_fractional_component = y_w / np.sqrt(
         y_w ** 2 + z_w ** 2 + 1e-16)  # The fraction of any "generalized lift" to be in the direction of beta
 
-    # generalized_alpha = np.clip(generalized_alpha, -90,
-    #                             90)  # TODO make the drag/moment functions not give negative results for alpha > 90.
-
     ### Compute normal quantities
     ### Note the (N)ormal, (A)ligned coordinate system. (See Jorgensen for definitions.)
     # M_n = sin_generalized_alpha * op_point.mach()
@@ -193,6 +244,8 @@ def fuselage_aerodynamics(
 
 
 if __name__ == '__main__':
+    import aerosandbox as asb
+
     fuselage = Fuselage(
         xsecs=[
             FuselageXSec(
@@ -206,21 +259,24 @@ if __name__ == '__main__':
     aero = fuselage_aerodynamics(
         fuselage=fuselage,
         op_point=OperatingPoint(
-            velocity=10,
+            atmosphere=asb.Atmosphere(altitude=0000),
+            velocity=50,
             alpha=10,
             beta=5
         )
     )
     print(aero)
 
-    from aerosandbox.tools.pretty_plots import plt, show_plot, contour, equal
+    import matplotlib.pyplot as plt
+    import aerosandbox.tools.pretty_plots as p
 
     fig, ax = plt.subplots(1, 2)
-    alpha = np.linspace(-60, 60, 1000)
+    alpha = np.linspace(-20, 20, 1000)
     aero = fuselage_aerodynamics(
         fuselage=fuselage,
         op_point=OperatingPoint(
-            velocity=10,
+            atmosphere=asb.Atmosphere(altitude=0000),
+            velocity=50,
             alpha=alpha,
         )
     )
@@ -228,13 +284,15 @@ if __name__ == '__main__':
     plt.plot(alpha, aero["L"])
     plt.xlabel("Angle of Attack [deg]")
     plt.ylabel("Lift Force [N]")
+    p.set_ticks(10,2)
 
     plt.sca(ax[1])
     plt.plot(alpha, aero["D"])
     plt.xlabel("Angle of Attack [deg]")
     plt.ylabel("Drag Force [N]")
+    p.set_ticks(10,2)
 
-    show_plot(
+    p.show_plot(
         "Fuselage Aerodynamics"
     )
 
@@ -243,12 +301,18 @@ if __name__ == '__main__':
     aero = fuselage_aerodynamics(
         fuselage=fuselage,
         op_point=OperatingPoint(
-            velocity=10,
+            atmosphere=asb.Atmosphere(altitude=10000),
+            velocity=50,
             alpha=Alpha,
             beta=Beta,
         )
     )
     from aerosandbox.tools.string_formatting import eng_string
-    contour(Beta, Alpha, aero["L"], levels=30, colorbar_label="Lift $L$ [N]", linelabels_format=lambda s: eng_string(s, unit="N"))
-    equal()
-    show_plot("3D Fuselage Lift", r"$\beta$ [deg]", r"$\alpha$ [deg]")
+
+    p.contour(
+        Beta, Alpha, aero["L"],
+        levels=30, colorbar_label="Lift $L$ [N]",
+        linelabels_format=lambda s: eng_string(s, unit="N")
+    )
+    p.equal()
+    p.show_plot("3D Fuselage Lift", r"$\beta$ [deg]", r"$\alpha$ [deg]")
