@@ -20,7 +20,8 @@ airplane = asb.Airplane(
                     chord=0.18,
                     twist=2,  # degrees
                     airfoil=wing_airfoil,  # Airfoils are blended between a given XSec and the next one.
-                    control_surface_is_symmetric=True,  # Flap (ctrl. surfs. applied between this XSec and the next one.)
+                    control_surface_is_symmetric=True,
+                    # Flap (ctrl. surfs. applied between this XSec and the next one.)
                     control_surface_deflection=0,  # degrees
                 ),
                 asb.WingXSec(  # Mid
