@@ -154,16 +154,36 @@ class Airfoil(Polygon):
                         cache_filename: str = None,
                         xfoil_kwargs: Dict[str, Any] = None,
                         unstructured_interpolated_model_kwargs: Dict[str, Any] = None,
-                        make_360_deg_model=True
                         ) -> None:
         """
-        Generates airfoil polars (CL, CD, CM functions) and self
+        Generates airfoil polars (CL, CD, CM functions) and assigns them in-place to this Airfoil's polar functions.
+
+        In other words, when this function is run, the following functions will be added (or overwritten) to the instance:
+            * Airfoil.CL_function(alpha, Re, mach, deflection)
+            * Airfoil.CD_function(alpha, Re, mach, deflection)
+            * Airfoil.CM_function(alpha, Re, mach, deflection)
+
+        Where alpha is in degrees. Right now, deflection is not used.
+
+        Args:
+
+            alphas: The range of alphas to sample from XFoil at.
+
+            Res: The range of Reynolds numbers to sample from XFoil at.
+
+            cache_filename: A path-like filename (ideally a "*.json" file) that can be used to cache the XFoil
+            results, making it much faster to regenerate the results.
+
+            xfoil_kwargs: Keyword arguments to pass into the AeroSandbox XFoil module. See the aerosandbox.XFoil
+            constructor for options.
+
+            unstructured_interpolated_model_kwargs: Keyword arguments to pass into the UnstructuredInterpolatedModels
+            that contain the polars themselves. See the aerosandbox.UnstructuredInterpolatedModel constructor for
+            options.
 
         Warning: In-place operation! Modifies this Airfoil object by setting Airfoil.CL_function, etc. to the new
         polars.
 
-        # TODO document parameters
-
         Returns: None (in-place)
 
         """
@@ -241,7 +261,8 @@ class Airfoil(Polygon):
                 with open(cache_filename, "w+") as f:
                     json.dump(
                         {k: v.tolist() for k, v in data.items()},
-                        f
+                        f,
+                        indent=4
                     )
 
         ### Save the raw data as an instance attribute for later use
@@ -289,6 +310,22 @@ class Airfoil(Polygon):
             **unstructured_interpolated_model_kwargs
         )
 
+        ### Determine if separated
+        alpha_stall_positive = np.max(data["alpha"])  # Across all Re
+        alpha_stall_negative = np.min(data["alpha"])  # Across all Re
+
+        def separation_parameter(alpha, Re=0):
+            """
+            Positive if separated, negative if attached.
+
+            This will be an input to a tanh() sigmoid blend via asb.numpy.blend(), so a value of 1 means the flow is
+            ~90% separated, and a value of -1 means the flow is ~90% attached.
+            """
+            return 0.5 * np.softmax(
+                alpha - alpha_stall_positive,
+                alpha_stall_negative - alpha
+            )
+
         ### Make the interpolators for separated aerodynamics
         from aerosandbox.aerodynamics.aero_2D.airfoil_polar_functions import airfoil_coefficients_post_stall
 
@@ -313,22 +350,6 @@ class Airfoil(Polygon):
             y_data=CM_if_separated
         )
 
-        ### Determine if separated
-        alpha_stall_positive = np.max(data["alpha"])  # Across all Re
-        alpha_stall_negative = np.min(data["alpha"])  # Across all Re
-
-        def separation_parameter(alpha, Re=0):
-            """
-            Positive if separated, negative if attached.
-
-            This will be an input to a tanh() sigmoid blend via asb.numpy.blend(), so a value of 1 means the flow is
-            ~90% separated, and a value of -1 means the flow is ~90% attached.
-            """
-            return 0.5 * np.softmax(
-                alpha - alpha_stall_positive,
-                alpha_stall_negative - alpha
-            )
-
         def CL_function(alpha, Re, mach=0, deflection=0):
             alpha = np.mod(alpha + 180, 360) - 180  # Keep alpha in the valid range.
             CL_attached = CL_attached_interpolator({
@@ -474,7 +495,7 @@ class Airfoil(Polygon):
             plt.axis("equal")
             plt.xlabel(r"$x/c$")
             plt.ylabel(r"$y/c$")
-            plt.title("%s Airfoil" % self.name)
+            plt.title(f"{self.name} Airfoil")
             plt.tight_layout()
             if show:
                 plt.show()
@@ -510,7 +531,7 @@ class Airfoil(Polygon):
                 xaxis_title="x/c",
                 yaxis_title="y/c",
                 yaxis=dict(scaleanchor="x", scaleratio=1),
-                title="%s Airfoil" % self.name
+                title=f"{self.name} Airfoil"
             )
             if show:
                 fig.show()
