@@ -1,44 +1,93 @@
 from aerosandbox import AeroSandboxObject
 from aerosandbox.geometry.common import *
-from typing import List, Union
-from numpy import pi
-from textwrap import dedent
-from pathlib import Path
+from typing import List, Dict, Any, Union
 import aerosandbox.geometry.mesh_utilities as mesh_utils
 
 
 class Airplane(AeroSandboxObject):
     """
     Definition for an airplane.
+
+    Anatomy of an Airplane:
+
+        An Airplane consists chiefly of a collection of wings and fuselages. These can be accessed with
+        `Airplane.wings` and `Airplane.fuselages`, which gives a list of those respective components. Each wing is a
+        Wing object, and each fuselage is a Fuselage object.
     """
 
     def __init__(self,
-                 name: str = "Untitled",  # A sensible name for your airplane.
-                 xyz_ref: np.ndarray = np.array([0, 0, 0]),  # Ref. point for moments; should be the center of gravity.
-                 wings: List['Wing'] = None,  # A list of Wing objects.
-                 fuselages: List['Fuselage'] = None,  # A list of Fuselage objects.
-                 s_ref: float = None,  # If not set, populates from first wing object.
-                 c_ref: float = None,  # See above
-                 b_ref: float = None,  # See above
+                 name: str = "Untitled",
+                 xyz_ref: Union[np.ndarray, List] = np.array([0, 0, 0]),
+                 wings: List['Wing'] = None,
+                 fuselages: List['Fuselage'] = None,
+                 s_ref: float = None,
+                 c_ref: float = None,
+                 b_ref: float = None,
+                 analysis_specific_options: Dict[type, Dict[str, Any]] = None
                  ):
+        """
+        Defines a new airplane.
+
+        Args:
+
+            name: Name of the airplane [optional]. It can help when debugging to give the airplane a sensible name.
+
+            xyz_ref: An array-like that gives the x-, y-, and z- reference point of the airplane, used when computing
+            moments and stability derivatives. Generally, this should be the center of gravity.
+
+                # In a future version, this will be deprecated and replaced with asb.MassProperties.
+
+            wings: A list of Wing objects that are a part of the airplane.
+
+            fuselages: A list of Fuselage objects that are a part of the airplane.
+
+            s_ref: Reference area. If undefined, it's set from the area of the first Wing object. # Note: will be deprecated
+
+            c_ref: Reference chord. If undefined, it's set from the mean aerodynamic chord of the first Wing object. # Note: will be deprecated
+
+            b_ref: Reference span. If undefined, it's set from the span of the first Wing object. # Note: will be deprecated
+
+            analysis_specific_options: Analysis-specific options are additional constants or modeling assumptions
+            that should be passed on to specific analyses and associated with this specific geometry object.
+
+                This should be a dictionary where:
+
+                    * Keys are specific analysis types (typically a subclass of asb.ExplicitAnalysis or
+                    asb.ImplicitAnalysis), but if you decide to write your own analysis and want to make this key
+                    something else (like a string), that's totally fine - it's just a unique identifier for the
+                    specific analysis you're running.
+
+                    * Values are a dictionary of key:value pairs, where:
+
+                        * Keys are strings.
+
+                        * Values are some value you want to assign.
+
+                This is more easily demonstrated / understood with an example:
+
+                >>> analysis_specific_options = {
+                >>>     asb.AeroBuildup: dict(
+                >>>         include_wave_drag=True,
+                >>>     )
+                >>> }
+
+        """
+        ### Set defaults
+        if wings is None:
+            wings: List['Wing'] = []
+        if fuselages is None:
+            fuselages: List['Fuselage'] = []
+        if analysis_specific_options is None:
+            analysis_specific_options = {}
+
         ### Initialize
         self.name = name
-
         self.xyz_ref = np.array(xyz_ref)
+        self.wings = wings
+        self.fuselages = fuselages
+        self.analysis_specific_options = analysis_specific_options
 
-        ## Add the wing objects
-        if wings is not None:
-            self.wings = wings
-        else:
-            self.wings: List['Wing'] = []
-
-        ## Add the fuselage objects
-        if fuselages is not None:
-            self.fuselages = fuselages
-        else:
-            self.fuselages: List['Fuselage'] = []
-
-        ## Assign reference values
+        ### Assign reference values
         try:
             main_wing = self.wings[0]
             if s_ref is None:
@@ -60,6 +109,8 @@ class Airplane(AeroSandboxObject):
                f"({n_wings} {'wing' if n_wings == 1 else 'wings'}, " \
                f"{n_fuselages} {'fuselage' if n_fuselages == 1 else 'fuselages'})"
 
+    # TODO def add_wing(wing: 'Wing') -> None
+
     def mesh_body(self,
                   method="quad",
                   thin_wings=False,
@@ -194,19 +245,8 @@ class Airplane(AeroSandboxObject):
         for wing in self.wings:
             if not wing.is_entirely_symmetric():
                 return False
-            for xsec in wing.xsecs:
-                if not (xsec.control_surface_is_symmetric or xsec.control_surface_deflection == 0):
-                    return False
-                if not wing.symmetric:
-                    if not xsec.xyz_le[1] == 0:
-                        return False
-                    if not xsec.twist == 0:
-                        if not (xsec.twist_axis[0] == 0 and xsec.twist_axis[2] == 0):
-                            return False
-                    if not xsec.airfoil.CL_function(0, 1e6, 0, 0) == 0:
-                        return False
-                    if not xsec.airfoil.Cm_function(0, 1e6, 0, 0) == 0:
-                        return False
+
+        # TODO add in logic for fuselages
 
         return True
 
@@ -239,104 +279,3 @@ class Airplane(AeroSandboxObject):
         aerodynamic_center = sum(wing_AC_area_products) / sum(wing_areas)
 
         return aerodynamic_center
-
-    def write_avl(self,
-                  filepath: Union[Path, str] = None,
-                  spanwise_panel_resolution: int = 12,
-                  chordwise_panel_resolution: int = 12,
-                  fuse_panel_resolution: int = 24,
-                  ) -> str:
-        """
-        Writes a .avl file corresponding to this airplane to a filepath.
-
-        For use with the AVL vortex-lattice-method aerodynamics analysis tool by Mark Drela at MIT.
-        AVL is available here: https://web.mit.edu/drela/Public/web/avl/
-
-        Args:
-            filepath: filepath (including the filename and .avl extension) [string]
-                If None, this function returns the .avl file as a string.
-
-        Returns: None
-
-        """
-        filepath = Path(filepath)
-
-        def clean(s):
-            """
-            Cleans up a multi-line string.
-            """
-            # return dedent(s)
-            return "\n".join([line.strip() for line in s.split("\n")])
-
-        string = ""
-
-        string += clean(f"""\
-        {self.name}
-        #Mach
-        0
-        #IYsym   IZsym   Zsym
-         0       0       0.0
-        #Sref    Cref    Bref
-        {self.s_ref} {self.c_ref} {self.b_ref}
-        #Xref    Yref    Zref
-        {self.xyz_ref[0]} {self.xyz_ref[1]} {self.xyz_ref[2]}
-        # CDp
-        0
-        """)
-
-        for wing in self.wings:
-            symmetry_line = "YDUPLICATE\n0" if wing.symmetric else ""
-
-            string += clean(f"""\
-            #{"=" * 50}
-            SURFACE
-            {wing.name}
-            #Nchordwise  Cspace   Nspanwise   Sspace
-            {chordwise_panel_resolution}   1.0   {spanwise_panel_resolution}   1.0
-            #
-            {symmetry_line}
-            #
-            ANGLE
-            0
-            """)
-
-            for xsec in wing.xsecs:
-
-                string += clean(f"""\
-                #{"-" * 50}
-                SECTION
-                #Xle    Yle    Zle     Chord   Ainc
-                {xsec.xyz_le[0]} {xsec.xyz_le[1]} {xsec.xyz_le[2]} {xsec.chord} {xsec.twist}
-                
-                AIRFOIL
-                {xsec.airfoil.repanel(50).write_dat(filepath=None, include_name=False)}
-                
-                #Cname   Cgain  Xhinge  HingeVec     SgnDup # TODO
-                #CONTROL
-                #csurf     1.0   0.75    0.0 0.0 0.0   1.0
-                
-                CLAF
-                {1 + 0.77 * xsec.airfoil.max_thickness()} # Computed using rule from avl_doc.txt
-                """)
-
-        for i, fuse in enumerate(self.fuselages):
-            fuse_filepath = Path(str(filepath) + f".fuse{i}")
-            fuse.write_avl_bfile(
-                filepath=fuse_filepath
-            )
-            string += clean(f"""\
-            #{"=" * 50}
-            BODY
-            {fuse.name}
-            {fuse_panel_resolution} 1
-            
-            BFIL
-            {fuse_filepath}
-            
-            """)
-
-        if filepath is not None:
-            with open(filepath, "w+") as f:
-                f.write(string)
-
-        return string
